@@ -2,12 +2,16 @@
 
 use std::{
     marker::PhantomData,
+    mem,
+    ops::{Deref, DerefMut},
     sync::{
-        Arc,
+        Arc, Mutex,
         atomic::{AtomicBool, Ordering},
     },
 };
 
+use bytes::BytesMut;
+use once_cell::sync::Lazy;
 use smoltcp::{
     phy::{self, Device, DeviceCapabilities},
     time::Instant,
@@ -16,8 +20,8 @@ use tokio::sync::mpsc;
 
 pub struct VirtTunDevice {
     capabilities: DeviceCapabilities,
-    in_buf: mpsc::UnboundedReceiver<Vec<u8>>,
-    out_buf: mpsc::UnboundedSender<Vec<u8>>,
+    in_buf: mpsc::UnboundedReceiver<TokenBuffer>,
+    out_buf: mpsc::UnboundedSender<TokenBuffer>,
     in_buf_avail: Arc<AtomicBool>,
 }
 
@@ -27,8 +31,8 @@ impl VirtTunDevice {
         capabilities: DeviceCapabilities,
     ) -> (
         Self,
-        mpsc::UnboundedReceiver<Vec<u8>>,
-        mpsc::UnboundedSender<Vec<u8>>,
+        mpsc::UnboundedReceiver<TokenBuffer>,
+        mpsc::UnboundedSender<TokenBuffer>,
         Arc<AtomicBool>,
     ) {
         let (iface_tx, iface_output) = mpsc::unbounded_channel();
@@ -81,7 +85,7 @@ impl Device for VirtTunDevice {
 }
 
 pub struct VirtRxToken<'a> {
-    buffer: Vec<u8>,
+    buffer: TokenBuffer,
     phantom_device: PhantomData<&'a VirtTunDevice>,
 }
 
@@ -101,9 +105,64 @@ impl phy::TxToken for VirtTxToken<'_> {
     where
         F: FnOnce(&mut [u8]) -> R,
     {
-        let mut buffer = vec![0u8; len];
+        let mut buffer = TokenBuffer::with_capacity(len);
+        unsafe {
+            buffer.set_len(len);
+        }
+
         let result = f(&mut buffer);
         self.0.out_buf.send(buffer).expect("channel closed unexpectly");
         result
     }
 }
+
+// Maximun number of TokenBuffer cached globally.
+//
+// Each of them has capacity 65536 (defined in tun/mod.rs), so 64 * 65536 = 4MB.
+const TOKEN_BUFFER_LIST_MAX_SIZE: usize = 64;
+static TOKEN_BUFFER_LIST: Lazy<Mutex<Vec<BytesMut>>> = Lazy::new(|| Mutex::new(Vec::new()));
+
+pub struct TokenBuffer {
+    buffer: BytesMut,
+}
+
+impl Drop for TokenBuffer {
+    fn drop(&mut self) {
+        let mut list = TOKEN_BUFFER_LIST.lock().unwrap();
+        if list.len() >= TOKEN_BUFFER_LIST_MAX_SIZE {
+            return;
+        }
+
+        let empty_buffer = BytesMut::new();
+        let mut buffer = mem::replace(&mut self.buffer, empty_buffer);
+        buffer.clear();
+
+        list.push(buffer);
+    }
+}
+
+impl TokenBuffer {
+    pub fn with_capacity(cap: usize) -> TokenBuffer {
+        let mut list = TOKEN_BUFFER_LIST.lock().unwrap();
+        if let Some(buffer) = list.pop() {
+            return TokenBuffer { buffer };
+        }
+        TokenBuffer {
+            buffer: BytesMut::with_capacity(cap),
+        }
+    }
+}
+
+impl Deref for TokenBuffer {
+    type Target = BytesMut;
+
+    fn deref(&self) -> &Self::Target {
+        &self.buffer
+    }
+}
+
+impl DerefMut for TokenBuffer {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.buffer
+    }
+}
