@@ -28,7 +28,11 @@ pub enum TcpRequestHeader {
 impl TcpRequestHeader {
     pub async fn read_from<R: AsyncRead + Unpin>(method: CipherKind, reader: &mut R) -> io::Result<TcpRequestHeader> {
         match method.category() {
-            CipherCategory::None | CipherCategory::Aead => Ok(TcpRequestHeader::Stream(
+            CipherCategory::None => Ok(TcpRequestHeader::Stream(
+                StreamTcpRequestHeader::read_from(reader).await?,
+            )),
+            #[cfg(feature = "aead-cipher")]
+            CipherCategory::Aead => Ok(TcpRequestHeader::Stream(
                 StreamTcpRequestHeader::read_from(reader).await?,
             )),
             #[cfg(feature = "stream-cipher")]
@@ -82,7 +86,7 @@ pub enum TcpRequestHeaderRef<'a> {
     Aead2022(Aead2022TcpRequestHeaderRef<'a>),
 }
 
-impl<'a> TcpRequestHeaderRef<'a> {
+impl TcpRequestHeaderRef<'_> {
     pub fn write_to_buf<B: BufMut>(&self, buf: &mut B) {
         match *self {
             TcpRequestHeaderRef::Stream(ref h) => h.write_to_buf(buf),
